Welcome to ahbicht's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Module Reference <apidoc/modules>



Indices
=======

* :ref:`modindex`
